pub struct U128(pub u128);Expand description
A u128 newtype that serializes as a decimal string in human-readable
formats (JSON / GraphQL) and as a bare u128 in binary (BCS).
Tuple Fields
0: u128Trait Implementations
Sourceimpl<'de> Deserialize<'de> for U128
impl<'de> Deserialize<'de> for U128
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl InputType for U128
impl InputType for U128
Sourcetype RawValueType = U128
type RawValueType = U128
The raw type used for validator. Read more
Sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
Sourcefn parse(value: Option<Value>) -> InputValueResult<Self>
fn parse(value: Option<Value>) -> InputValueResult<Self>
Parse from
Value. None represents undefined.Sourcefn as_raw_value(&self) -> Option<&Self::RawValueType>
fn as_raw_value(&self) -> Option<&Self::RawValueType>
Returns a reference to the raw value.
Sourcefn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
Sourceimpl Ord for U128
impl Ord for U128
Sourceimpl OutputType for U128
impl OutputType for U128
Sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
Sourceasync fn resolve(
&self,
_: &ContextSelectionSet<'_>,
_field: &Positioned<Field>,
) -> ServerResult<Value>
async fn resolve( &self, _: &ContextSelectionSet<'_>, _field: &Positioned<Field>, ) -> ServerResult<Value>
Resolve an output value to
async_graphql::Value.Sourcefn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
Sourceimpl PartialOrd for U128
impl PartialOrd for U128
Sourceimpl ScalarType for U128
impl ScalarType for U128
impl Copy for U128
impl Eq for U128
impl StructuralPartialEq for U128